@@ -20,7 +20,7 @@ my $l_SplitFrame = $l_MainWindow->SplitFrame
     '-padbefore' => 22,
     '-padafter' => 62,
     '-orientation' => 'vertical',
-    '-sliderposition' => 120
+    '-sliderposition' => 120,
    );
 
 $l_SplitFrame->Label
@@ -57,4 +57,4 @@ $l_SplitFrame->pack
     '-fill' => 'both',
    );
 
-Tk::MainLoop;
+Tk::MainLoop;
\ No newline at end of file
